==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.get_tw = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_vb = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "vb", {
        get: function () {
            return this.get_vb();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_u2 = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.get_x5 = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_zk = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zk", {
        get: function () {
            return this.get_zk();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_zb = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };
